@@ -18,7 +18,10 @@ use POE;
 use aliased 'POE::Kernel' => 'K';
 
 use base qw{ Class::Accessor::Fast };
-__PACKAGE__->mk_accessors( qw{ armies curplayer map nbdice wait_for _players _players_turn_done _players_turn_todo } );
+__PACKAGE__->mk_accessors( qw{
+    armies curplayer dst map nbdice src wait_for
+    _players _players_turn_done _players_turn_todo
+} );
 
 #--
 # METHODS
